'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

// The theme file is based on the specification at https://system-ui.com/theme
// e.g. for sport:
// const [sport300, sport400, sport500, sport600, sport800] = colors.blue

var colors = {
  reds: ["#660505", //news-100
  "#8B0000", //news-200
  "#AB0613", //news-300
  "#C70000", //news-400
  "#FF5943", //news-500
  "#FFBAC8", //news-600
  "#FFF4F2" //news-800
  ],
  oranges: ["#672005", //opinion-100
  "#8D2700", //opinion-200
  "#BD5318", //opinion-300
  "#E05E00", //opinion-400
  "#FF7F0F", //opinion-500
  "#F9B376", //opinion-600
  "#FEF9F5" //opinion-800
  ],
  blues: ["#003C60", //sport-100
  "#004E7C", //sport-200
  "#005689", //sport-300
  "#0084C6", //sport-400
  "#00B2FF", //sport-500
  "#90DCFF", //sport-600
  "#F1F8FC", //sport-800
  "#001536", //brand-100
  "#041F4A", //brand-300
  "#052962", //brand-400
  "#007ABC", //brand-500
  "#506991", //brand-600
  "#C1D8FC" //brand-800
  ],
  browns: ["#3E3323", //culture-100
  "#574835", //culture-200
  "#6B5840", //culture-300
  "#A1845C", //culture-400
  "#EACCA0", //culture-500
  "#E7D4B9", //culture-600
  "#FBF6EF" //culture-800
  ],
  pinks: ["#510043", //lifestyle-100
  "#650054", //lifestyle-200
  "#7D0068", //lifestyle-300
  "#BB3B80", //lifestyle-400
  "#FFABDB", //lifestyle-500
  "#FEC8D3", //lifestyle-600
  "#FEEEF7" //lifestyle-800
  ],
  yellows: ["#F3C100", //brandAlt-200
  "#FFD900", //brandAlt-300
  "#FFE500" //brandAlt-400
  ],
  greens: ["#185E36", //green-200
  "#22874D", //green-400
  "#4B8878", //labs-200
  "#65A897", //labs-300
  "#69D1CA" //labs-400
  ],
  grays: ["#000000", //neutral-0
  "#121212", //neutral-7
  "#1A1A1A", //neutral-10
  "#333333", //neutral-20
  "#767676", //neutral-46
  "#999999", //neutral-60
  "#DCDCDC", //neutral-86
  "#EDEDED", //neutral-93
  "#F6F6F6", //neutral-97
  "#FFFFFF", //neutral-100
  "#222527", //specialReport-100
  "#303538", //specialReport-200
  "#3F464A", //specialReport-300
  "#63717A", //specialReport-400
  "#ABC2C9", //specialReport-500
  "#33393D" //dynamo-400
  ]
};
var space = [0, 4, 8, 12, 16, 20, 24, 36, 48, 96];
var size = [24, 36, 44];
var breakpoints = [740, 980, 1140, 1300]; // Diverges from https://system-ui.com
// At these widths, there are tweaks to the
// fluid grid on mobile devices

var tweakpoints = [320, 375, 480, 660];
var transitions = [".2s cubic-bezier(.64, .57, .67, 1.53)", ".3s ease-in-out", ".65s ease-in-out"];

var transitions$1 = {
  "short": transitions[0],
  medium: transitions[1],
  "long": transitions[2]
};

var breakpoints$1 = {
  mobile: tweakpoints[0],
  mobileMedium: tweakpoints[1],
  mobileLandscape: tweakpoints[2],
  phablet: tweakpoints[3],
  tablet: breakpoints[0],
  desktop: breakpoints[1],
  leftCol: breakpoints[2],
  wide: breakpoints[3]
};

// Global colour names that correspond to https://www.theguardian.design/2a1e5182b/p/938810-colour/b/587ef3
var brand = {
  100: colors.blues[7],
  300: colors.blues[8],
  400: colors.blues[9],
  500: colors.blues[10],
  600: colors.blues[11],
  800: colors.blues[12],
  // legacy names: please do not use
  dark: colors.blues[8],
  main: colors.blues[9],
  bright: colors.blues[10],
  pastel: colors.blues[11],
  faded: colors.blues[12]
};
var brandAlt = {
  200: colors.yellows[0],
  300: colors.yellows[1],
  400: colors.yellows[2],
  // legacy names: please do not use
  dark: colors.yellows[1],
  main: colors.yellows[2]
}; // continue to expose legacy name for compatibility

var brandYellow = brandAlt;
var neutral = {
  0: colors.grays[0],
  7: colors.grays[1],
  10: colors.grays[2],
  20: colors.grays[3],
  46: colors.grays[4],
  60: colors.grays[5],
  86: colors.grays[6],
  93: colors.grays[7],
  97: colors.grays[8],
  100: colors.grays[9]
};
var error = {
  400: colors.reds[3],
  500: colors.reds[4],
  // legacy names: please do not use
  main: colors.reds[3],
  bright: colors.reds[4]
};
var success = {
  400: colors.greens[1],
  // legacy names: please do not use
  main: colors.greens[1]
};
var news = {
  100: colors.reds[0],
  200: colors.reds[1],
  300: colors.reds[2],
  400: colors.reds[3],
  500: colors.reds[4],
  600: colors.reds[5],
  800: colors.reds[6],
  // legacy names: please do not use
  dark: colors.reds[2],
  main: colors.reds[3],
  bright: colors.reds[4],
  pastel: colors.reds[5],
  faded: colors.reds[6]
};
var opinion = {
  100: colors.oranges[0],
  200: colors.oranges[1],
  300: colors.oranges[2],
  400: colors.oranges[3],
  500: colors.oranges[4],
  600: colors.oranges[5],
  800: colors.oranges[6],
  // legacy names: please do not use
  dark: colors.oranges[2],
  main: colors.oranges[3],
  bright: colors.oranges[4],
  pastel: colors.oranges[5],
  faded: colors.oranges[6]
};
var sport = {
  100: colors.blues[0],
  200: colors.blues[1],
  300: colors.blues[2],
  400: colors.blues[3],
  500: colors.blues[4],
  600: colors.blues[5],
  800: colors.blues[6],
  // legacy names: please do not use
  dark: colors.blues[2],
  main: colors.blues[3],
  bright: colors.blues[4],
  pastel: colors.blues[5],
  faded: colors.blues[6]
};
var culture = {
  100: colors.browns[0],
  200: colors.browns[1],
  300: colors.browns[2],
  400: colors.browns[3],
  500: colors.browns[4],
  600: colors.browns[5],
  800: colors.browns[6],
  // legacy names: please do not use
  dark: colors.browns[2],
  main: colors.browns[3],
  bright: colors.browns[4],
  pastel: colors.browns[5],
  faded: colors.browns[6]
};
var lifestyle = {
  100: colors.pinks[0],
  200: colors.pinks[1],
  300: colors.pinks[2],
  400: colors.pinks[3],
  500: colors.pinks[4],
  600: colors.pinks[5],
  800: colors.pinks[6],
  // legacy names: please do not use
  dark: colors.pinks[2],
  main: colors.pinks[3],
  bright: colors.pinks[4],
  pastel: colors.pinks[5],
  faded: colors.pinks[6]
};
var labs = {
  200: colors.greens[2],
  300: colors.greens[3],
  400: colors.greens[4],
  // legacy names: please do not use
  dark: colors.greens[3],
  main: colors.greens[4]
};

var background = {
  primary: neutral[100],
  secondary: neutral[97],
  inverse: neutral[10],
  ctaPrimary: brand[400],
  ctaPrimaryHover: "#234B8A",
  ctaSecondary: brand[800],
  ctaSecondaryHover: "#ACC9F7",
  ctaTertiaryHover: "#E5E5E5",
  input: neutral[100],
  inputChecked: brand[500]
};

var brandBackground = {
  primary: brand[400],
  inputChecked: neutral[100],
  ctaPrimary: neutral[100],
  ctaPrimaryHover: "#E0E0E0",
  ctaSecondary: brand[600],
  ctaSecondaryHover: "#234B8A",
  ctaTertiaryHover: brand[300]
};

var brandAltBackground = {
  primary: brandAlt[400],
  ctaPrimary: neutral[7],
  ctaPrimaryHover: "#454545",
  ctaSecondary: brandAlt[200],
  ctaSecondaryHover: "#F2AE00",
  ctaTertiaryHover: "#FFD213"
};

var border = {
  primary: neutral[60],
  secondary: neutral[86],
  success: success[400],
  error: error[400],
  ctaTertiary: brand[400],
  input: neutral[60],
  inputChecked: brand[500],
  inputHover: brand[500],
  inputActive: brand[500],
  focusHalo: sport[500]
};

var brandBorder = {
  primary: brand[800],
  success: success[400],
  error: error[500],
  ctaTertiary: neutral[100],
  input: brand[800],
  inputChecked: neutral[100],
  inputHover: neutral[100]
};

var brandAltBorder = {
  ctaTertiary: neutral[7]
};

var line = {
  primary: neutral[86]
};

var brandLine = {
  primary: brand[600]
};

var brandAltLine = {
  primary: neutral[7]
};

var text = {
  primary: neutral[7],
  supporting: neutral[46],
  success: success[400],
  error: error[400],
  ctaPrimary: neutral[100],
  ctaSecondary: brand[400],
  ctaTertiary: brand[400],
  anchorPrimary: brand[500],
  anchorSecondary: neutral[7],
  userInput: neutral[7],
  inputLabel: neutral[7],
  inputLabelSupporting: neutral[46],
  inputChecked: brand[400],
  //choice card only
  inputHover: brand[400],
  //choice card only
  groupLabel: neutral[7],
  groupLabelSupporting: neutral[46]
};

var brandText = {
  primary: neutral[100],
  supporting: brand[800],
  success: success[400],
  error: error[500],
  ctaPrimary: brand[400],
  ctaSecondary: neutral[100],
  ctaTertiary: neutral[100],
  anchorPrimary: neutral[100],
  userInput: neutral[100],
  inputLabel: neutral[100],
  inputLabelSupporting: brand[800]
};

var brandAltText = {
  primary: neutral[7],
  supporting: neutral[60],
  ctaPrimary: neutral[100],
  ctaSecondary: neutral[7],
  ctaTertiary: neutral[7],
  anchorPrimary: neutral[7]
};

/*
This API is now deprecated. Use the values under
@guardian/src-foundations/size instead
*/

var size$1 = {
  xsmall: size[0],
  small: size[1],
  medium: size[2]
};

function _classCallCheck(instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
}

function _defineProperties(target, props) {
  for (var i = 0; i < props.length; i++) {
    var descriptor = props[i];
    descriptor.enumerable = descriptor.enumerable || false;
    descriptor.configurable = true;
    if ("value" in descriptor) descriptor.writable = true;
    Object.defineProperty(target, descriptor.key, descriptor);
  }
}

function _createClass(Constructor, protoProps, staticProps) {
  if (protoProps) _defineProperties(Constructor.prototype, protoProps);
  if (staticProps) _defineProperties(Constructor, staticProps);
  return Constructor;
}

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

var TAB_KEY_CODE = 9;
/**
 * Source: Blueprint https://blueprintjs.com/
 * https://github.com/palantir/blueprint/blob/06a186c90758bbdca604ed6d7bf639c3d05b1fa0/packages/core/src/common/interactionMode.ts
 * A nifty little class that maintains event handlers to add a class to the container element
 * when entering "mouse mode" (on a `mousedown` event) and remove it when entering "keyboard mode"
 * (on a `tab` key `keydown` event).
 * Requires @babel/plugin-proposal-class-properties
 */

var InteractionModeEngine = /*#__PURE__*/function () {
  // tslint:disable-next-line:no-constructor-vars
  function InteractionModeEngine(container, className) {
    var _this = this;

    _classCallCheck(this, InteractionModeEngine);

    this.container = container;
    this.className = className;

    _defineProperty(this, "isRunning", false);

    _defineProperty(this, "handleKeyDown", function (e) {
      if (e.which === TAB_KEY_CODE) {
        _this.reset();

        _this.container.addEventListener("mousedown", _this.handleMouseDown);
      }
    });

    _defineProperty(this, "handleMouseDown", function () {
      _this.reset();

      _this.container.classList.add(_this.className);

      _this.container.addEventListener("keydown", _this.handleKeyDown);
    });
  }
  /** Returns whether the engine is currently running. */


  _createClass(InteractionModeEngine, [{
    key: "isActive",
    value: function isActive() {
      return this.isRunning;
    }
    /** Enable behavior which applies the given className when in mouse mode. */

  }, {
    key: "start",
    value: function start() {
      this.container.addEventListener("mousedown", this.handleMouseDown);
      this.isRunning = true;
    }
    /** Disable interaction mode behavior and remove className from container. */

  }, {
    key: "stop",
    value: function stop() {
      this.reset();
      this.isRunning = false;
    }
  }, {
    key: "reset",
    value: function reset() {
      this.container.classList.remove(this.className);
      this.container.removeEventListener("keydown", this.handleKeyDown);
      this.container.removeEventListener("mousedown", this.handleMouseDown);
    }
  }]);

  return InteractionModeEngine;
}();
var FOCUS_DISABLED = "src-focus-disabled";
var focusEngine = new InteractionModeEngine(document.documentElement, FOCUS_DISABLED);

var rootPixelFontSize = 16;
var pxToRem = function pxToRem(px) {
  return px / rootPixelFontSize;
};

var space$1 = {
  1: space[1],
  2: space[2],
  3: space[3],
  4: space[4],
  5: space[5],
  6: space[6],
  9: space[7],
  12: space[8],
  24: space[9]
};
/* TODO: this should be exposed as a number instead of a string,
   so consumers can perform calculations on it */

var remSpace = {
  1: "".concat(pxToRem(space$1[1]), "rem"),
  2: "".concat(pxToRem(space$1[2]), "rem"),
  3: "".concat(pxToRem(space$1[3]), "rem"),
  4: "".concat(pxToRem(space$1[4]), "rem"),
  5: "".concat(pxToRem(space$1[5]), "rem"),
  6: "".concat(pxToRem(space$1[6]), "rem"),
  9: "".concat(pxToRem(space$1[9]), "rem"),
  12: "".concat(pxToRem(space$1[12]), "rem"),
  24: "".concat(pxToRem(space$1[24]), "rem")
};

var palette = {
  // functional colours (default)
  background: background,
  border: border,
  line: line,
  text: text,
  // functional colours (brand)
  brandBackground: brandBackground,
  brandBorder: brandBorder,
  brandLine: brandLine,
  brandText: brandText,
  // functional colours (brandAlt)
  brandAltBackground: brandAltBackground,
  brandAltBorder: brandAltBorder,
  brandAltLine: brandAltLine,
  brandAltText: brandAltText,
  // global colours
  brand: brand,
  brandAlt: brandAlt,
  brandYellow: brandYellow,
  neutral: neutral,
  error: error,
  success: success,
  news: news,
  opinion: opinion,
  sport: sport,
  culture: culture,
  lifestyle: lifestyle,
  labs: labs
};

exports.background = background;
exports.border = border;
exports.brand = brand;
exports.brandAlt = brandAlt;
exports.brandAltBackground = brandAltBackground;
exports.brandAltBorder = brandAltBorder;
exports.brandAltLine = brandAltLine;
exports.brandAltText = brandAltText;
exports.brandBackground = brandBackground;
exports.brandBorder = brandBorder;
exports.brandLine = brandLine;
exports.brandText = brandText;
exports.brandYellow = brandYellow;
exports.breakpoints = breakpoints$1;
exports.culture = culture;
exports.error = error;
exports.labs = labs;
exports.lifestyle = lifestyle;
exports.line = line;
exports.neutral = neutral;
exports.news = news;
exports.opinion = opinion;
exports.palette = palette;
exports.remSpace = remSpace;
exports.size = size$1;
exports.space = space$1;
exports.sport = sport;
exports.success = success;
exports.text = text;
exports.transitions = transitions$1;
