'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

// The theme file is based on the specification at https://system-ui.com/theme
var breakpoints = [740, 980, 1140, 1300]; // Diverges from https://system-ui.com
// At these widths, there are tweaks to the
// fluid grid on mobile devices

var tweakpoints = [320, 375, 480, 660];

var breakpoints$1 = {
  mobile: tweakpoints[0],
  mobileMedium: tweakpoints[1],
  mobileLandscape: tweakpoints[2],
  phablet: tweakpoints[3],
  tablet: breakpoints[0],
  desktop: breakpoints[1],
  leftCol: breakpoints[2],
  wide: breakpoints[3]
};

function _classCallCheck(instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
}

function _defineProperties(target, props) {
  for (var i = 0; i < props.length; i++) {
    var descriptor = props[i];
    descriptor.enumerable = descriptor.enumerable || false;
    descriptor.configurable = true;
    if ("value" in descriptor) descriptor.writable = true;
    Object.defineProperty(target, descriptor.key, descriptor);
  }
}

function _createClass(Constructor, protoProps, staticProps) {
  if (protoProps) _defineProperties(Constructor.prototype, protoProps);
  if (staticProps) _defineProperties(Constructor, staticProps);
  return Constructor;
}

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

var TAB_KEY_CODE = 9;
/**
 * Source: Blueprint https://blueprintjs.com/
 * https://github.com/palantir/blueprint/blob/06a186c90758bbdca604ed6d7bf639c3d05b1fa0/packages/core/src/common/interactionMode.ts
 * A nifty little class that maintains event handlers to add a class to the container element
 * when entering "mouse mode" (on a `mousedown` event) and remove it when entering "keyboard mode"
 * (on a `tab` key `keydown` event).
 * Requires @babel/plugin-proposal-class-properties
 */

var InteractionModeEngine = /*#__PURE__*/function () {
  // tslint:disable-next-line:no-constructor-vars
  function InteractionModeEngine(container, className) {
    var _this = this;

    _classCallCheck(this, InteractionModeEngine);

    this.container = container;
    this.className = className;

    _defineProperty(this, "isRunning", false);

    _defineProperty(this, "handleKeyDown", function (e) {
      if (e.which === TAB_KEY_CODE) {
        _this.reset();

        _this.container.addEventListener("mousedown", _this.handleMouseDown);
      }
    });

    _defineProperty(this, "handleMouseDown", function () {
      _this.reset();

      _this.container.classList.add(_this.className);

      _this.container.addEventListener("keydown", _this.handleKeyDown);
    });
  }
  /** Returns whether the engine is currently running. */


  _createClass(InteractionModeEngine, [{
    key: "isActive",
    value: function isActive() {
      return this.isRunning;
    }
    /** Enable behavior which applies the given className when in mouse mode. */

  }, {
    key: "start",
    value: function start() {
      this.container.addEventListener("mousedown", this.handleMouseDown);
      this.isRunning = true;
    }
    /** Disable interaction mode behavior and remove className from container. */

  }, {
    key: "stop",
    value: function stop() {
      this.reset();
      this.isRunning = false;
    }
  }, {
    key: "reset",
    value: function reset() {
      this.container.classList.remove(this.className);
      this.container.removeEventListener("keydown", this.handleKeyDown);
      this.container.removeEventListener("mousedown", this.handleMouseDown);
    }
  }]);

  return InteractionModeEngine;
}();
var FOCUS_DISABLED = "src-focus-disabled";
var focusEngine = new InteractionModeEngine(document.documentElement, FOCUS_DISABLED);

// babel * typescript * rollup = ¯\_(ツ)_/¯

var minWidth = function minWidth(from) {
  return "@media (min-width: ".concat("".concat(from, "px"), ")");
};

var maxWidth = function maxWidth(until) {
  return "@media (max-width: ".concat("".concat(until - 1, "px"), ")");
};

var minWidthMaxWidth = function minWidthMaxWidth(from, until) {
  return "@media (min-width: ".concat("".concat(from, "px"), ") and (max-width: ", "".concat(until - 1, "px"), ")");
}; // e.g. from.*


var from = {
  mobile: minWidth(breakpoints$1.mobile),
  mobileMedium: minWidth(breakpoints$1.mobileMedium),
  mobileLandscape: minWidth(breakpoints$1.mobileLandscape),
  phablet: minWidth(breakpoints$1.phablet),
  tablet: minWidth(breakpoints$1.tablet),
  desktop: minWidth(breakpoints$1.desktop),
  leftCol: minWidth(breakpoints$1.leftCol),
  wide: minWidth(breakpoints$1.wide)
}; // e.g. until.*

var until = {
  mobile: maxWidth(breakpoints$1.mobile),
  mobileMedium: maxWidth(breakpoints$1.mobileMedium),
  mobileLandscape: maxWidth(breakpoints$1.mobileLandscape),
  phablet: maxWidth(breakpoints$1.phablet),
  tablet: maxWidth(breakpoints$1.tablet),
  desktop: maxWidth(breakpoints$1.desktop),
  leftCol: maxWidth(breakpoints$1.leftCol),
  wide: maxWidth(breakpoints$1.wide)
}; // e.g. between.*.and.*

var between = {
  mobile: {
    and: {
      mobileMedium: minWidthMaxWidth(breakpoints$1.mobile, breakpoints$1.mobileMedium),
      mobileLandscape: minWidthMaxWidth(breakpoints$1.mobile, breakpoints$1.mobileLandscape),
      phablet: minWidthMaxWidth(breakpoints$1.mobile, breakpoints$1.phablet),
      tablet: minWidthMaxWidth(breakpoints$1.mobile, breakpoints$1.tablet),
      desktop: minWidthMaxWidth(breakpoints$1.mobile, breakpoints$1.desktop),
      leftCol: minWidthMaxWidth(breakpoints$1.mobile, breakpoints$1.leftCol),
      wide: minWidthMaxWidth(breakpoints$1.mobileMedium, breakpoints$1.wide)
    }
  },
  mobileMedium: {
    and: {
      mobileLandscape: minWidthMaxWidth(breakpoints$1.mobileMedium, breakpoints$1.mobileLandscape),
      phablet: minWidthMaxWidth(breakpoints$1.mobileMedium, breakpoints$1.phablet),
      tablet: minWidthMaxWidth(breakpoints$1.mobileMedium, breakpoints$1.tablet),
      desktop: minWidthMaxWidth(breakpoints$1.mobileMedium, breakpoints$1.desktop),
      leftCol: minWidthMaxWidth(breakpoints$1.mobileMedium, breakpoints$1.leftCol),
      wide: minWidthMaxWidth(breakpoints$1.mobileMedium, breakpoints$1.wide)
    }
  },
  mobileLandscape: {
    and: {
      phablet: minWidthMaxWidth(breakpoints$1.mobileLandscape, breakpoints$1.phablet),
      tablet: minWidthMaxWidth(breakpoints$1.mobileLandscape, breakpoints$1.tablet),
      desktop: minWidthMaxWidth(breakpoints$1.mobileLandscape, breakpoints$1.desktop),
      leftCol: minWidthMaxWidth(breakpoints$1.mobileLandscape, breakpoints$1.leftCol),
      wide: minWidthMaxWidth(breakpoints$1.mobileLandscape, breakpoints$1.wide)
    }
  },
  phablet: {
    and: {
      tablet: minWidthMaxWidth(breakpoints$1.phablet, breakpoints$1.tablet),
      desktop: minWidthMaxWidth(breakpoints$1.phablet, breakpoints$1.desktop),
      leftCol: minWidthMaxWidth(breakpoints$1.phablet, breakpoints$1.leftCol),
      wide: minWidthMaxWidth(breakpoints$1.phablet, breakpoints$1.wide)
    }
  },
  tablet: {
    and: {
      desktop: minWidthMaxWidth(breakpoints$1.tablet, breakpoints$1.desktop),
      leftCol: minWidthMaxWidth(breakpoints$1.tablet, breakpoints$1.leftCol),
      wide: minWidthMaxWidth(breakpoints$1.tablet, breakpoints$1.wide)
    }
  },
  desktop: {
    and: {
      leftCol: minWidthMaxWidth(breakpoints$1.desktop, breakpoints$1.leftCol),
      wide: minWidthMaxWidth(breakpoints$1.desktop, breakpoints$1.wide)
    }
  },
  leftCol: {
    and: {
      wide: minWidthMaxWidth(breakpoints$1.leftCol, breakpoints$1.wide)
    }
  }
};

exports.between = between;
exports.breakpoints = breakpoints$1;
exports.from = from;
exports.until = until;
