import { text, border, background, brandText, brandBackground, brandBorder, brandAltText, brandAltBackground, brandAltBorder } from '@guardian/src-foundations/palette';

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    if (enumerableOnly) symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    });
    keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};

    if (i % 2) {
      ownKeys(Object(source), true).forEach(function (key) {
        _defineProperty(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys(Object(source)).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }

  return target;
}

var accordionDefault = {
  accordion: {
    textPrimary: text.primary,
    borderPrimary: border.primary
  }
};

var buttonDefault = {
  button: {
    textPrimary: text.ctaPrimary,
    backgroundPrimary: background.ctaPrimary,
    backgroundPrimaryHover: background.ctaPrimaryHover,
    textSecondary: text.ctaSecondary,
    backgroundSecondary: background.ctaSecondary,
    backgroundSecondaryHover: background.ctaSecondaryHover,
    textTertiary: text.ctaTertiary,
    backgroundTertiaryHover: background.ctaTertiaryHover,
    borderTertiary: border.ctaTertiary,
    textSubdued: text.ctaSecondary
  }
};
var buttonBrand = {
  button: {
    textPrimary: brandText.ctaPrimary,
    backgroundPrimary: brandBackground.ctaPrimary,
    backgroundPrimaryHover: brandBackground.ctaPrimaryHover,
    textSecondary: brandText.ctaSecondary,
    backgroundSecondary: brandBackground.ctaSecondary,
    backgroundSecondaryHover: brandBackground.ctaSecondaryHover,
    textTertiary: brandText.ctaTertiary,
    backgroundTertiaryHover: brandBackground.ctaTertiaryHover,
    borderTertiary: brandBorder.ctaTertiary,
    textSubdued: brandText.ctaSecondary
  }
};
var buttonBrandAlt = {
  button: {
    textPrimary: brandAltText.ctaPrimary,
    backgroundPrimary: brandAltBackground.ctaPrimary,
    backgroundPrimaryHover: brandAltBackground.ctaPrimaryHover,
    textSecondary: brandAltText.ctaSecondary,
    backgroundSecondary: brandAltBackground.ctaSecondary,
    backgroundSecondaryHover: brandAltBackground.ctaSecondaryHover,
    textTertiary: brandAltText.ctaTertiary,
    backgroundTertiaryHover: brandAltBackground.ctaTertiaryHover,
    borderTertiary: brandAltBorder.ctaTertiary,
    textSubdued: brandAltText.ctaSecondary
  }
}; // continue to expose legacy theme names

var buttonLight = buttonDefault;
var buttonBrandYellow = buttonBrandAlt;

var inlineErrorDefault = {
  inlineError: {
    text: text.error
  }
};
var inlineErrorBrand = {
  inlineError: {
    text: brandText.error
  }
}; // continue to expose legacy theme names

var inlineErrorLight = inlineErrorDefault;

var checkboxDefault = _objectSpread2({
  checkbox: {
    border: border.input,
    borderHover: border.inputHover,
    borderChecked: border.inputChecked,
    borderError: border.error,
    backgroundChecked: background.inputChecked,
    textLabel: text.inputLabel,
    textLabelSupporting: text.inputLabelSupporting,
    textIndeterminate: text.supporting
  }
}, inlineErrorDefault);
var checkboxBrand = _objectSpread2({
  checkbox: {
    border: brandBorder.input,
    borderHover: brandBorder.inputHover,
    borderChecked: brandBorder.inputChecked,
    borderError: brandBorder.error,
    backgroundChecked: brandBackground.inputChecked,
    textLabel: brandText.inputLabel,
    textLabelSupporting: brandText.inputLabelSupporting,
    textIndeterminate: brandText.supporting
  }
}, inlineErrorBrand); // continue to expose legacy theme names

var checkboxLight = checkboxDefault;

var choiceCardDefault = _objectSpread2({
  choiceCard: {
    textLabel: text.supporting,
    textLabelSupporting: text.supporting,
    textGroupLabel: text.groupLabel,
    textGroupLabelSupporting: text.groupLabelSupporting,
    border: border.input,
    textChecked: text.inputChecked,
    backgroundChecked: "#E3F6FF",
    backgroundTick: background.inputChecked,
    borderChecked: border.inputChecked,
    textHover: text.inputHover,
    borderHover: border.inputHover,
    textError: text.error,
    borderError: border.error
  }
}, inlineErrorDefault);

var linkDefault = {
  link: {
    textPrimary: text.anchorPrimary,
    textPrimaryHover: text.anchorPrimary,
    textSecondary: text.anchorSecondary,
    textSecondaryHover: text.anchorSecondary
  }
};
var linkBrand = {
  link: {
    textPrimary: brandText.anchorPrimary,
    textPrimaryHover: brandText.anchorPrimary
  }
};
var linkBrandAlt = {
  link: {
    textPrimary: brandAltText.anchorPrimary,
    textPrimaryHover: brandAltText.anchorPrimary
  }
}; // continue to expose legacy theme names

var linkLight = linkDefault;
var linkBrandYellow = linkBrandAlt;

var radioDefault = _objectSpread2({
  radio: {
    borderHover: border.inputHover,
    border: border.input,
    backgroundChecked: background.inputChecked,
    textLabel: text.inputLabel,
    textLabelSupporting: text.inputLabelSupporting,
    borderError: border.error
  }
}, inlineErrorLight);
var radioBrand = _objectSpread2({
  radio: {
    borderHover: brandBorder.inputHover,
    border: brandBorder.input,
    backgroundChecked: brandBackground.inputChecked,
    textLabel: brandText.inputLabel,
    textLabelSupporting: brandText.supporting,
    borderError: brandBorder.error
  }
}, inlineErrorBrand); // continue to expose legacy theme names

var radioLight = radioDefault;

var textInputDefault = _objectSpread2({
  textInput: {
    textUserInput: text.userInput,
    textLabel: text.inputLabel,
    textLabelOptional: text.supporting,
    textLabelSupporting: text.supporting,
    textError: text.error,
    backgroundInput: background.input,
    border: border.input,
    borderActive: border.inputActive,
    borderError: border.error
  }
}, inlineErrorDefault); // continue to expose legacy theme names

var textInputLight = textInputDefault;

var defaultTheme = _objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2({}, buttonDefault), checkboxDefault), choiceCardDefault), inlineErrorDefault), linkDefault), radioDefault), textInputDefault), buttonLight), checkboxLight), inlineErrorLight), linkLight), radioLight), textInputLight);
var brand = _objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2({}, buttonBrand), checkboxBrand), inlineErrorBrand), linkBrand), radioBrand);
var brandAlt = _objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2({}, buttonBrandAlt), linkBrandAlt), buttonBrandYellow), linkBrandYellow); // continue to expose legacy theme names

var light = defaultTheme;
var brandYellow = brandAlt;

export { accordionDefault, brand, brandAlt, brandYellow, buttonBrand, buttonBrandAlt, buttonBrandYellow, buttonDefault, buttonLight, checkboxBrand, checkboxDefault, checkboxLight, choiceCardDefault, defaultTheme, inlineErrorBrand, inlineErrorDefault, inlineErrorLight, light, linkBrand, linkBrandAlt, linkBrandYellow, linkDefault, linkLight, radioBrand, radioDefault, radioLight, textInputDefault, textInputLight };
